package com.mortals.xhx.base.login.web;

import cn.hutool.core.util.IdUtil;
import com.alibaba.fastjson.JSONObject;
import com.mortals.framework.service.IAuthTokenService;
import com.mortals.framework.util.DateUtils;
import com.mortals.framework.util.StringUtils;
import com.mortals.framework.web.BaseCRUDJsonBodyMappingController;
import com.mortals.xhx.module.customer.model.CustomerEntity;
import com.mortals.xhx.module.customer.service.CustomerService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import java.util.HashMap;
import java.util.Map;

@RestController
@RequestMapping("customer/login")
public class CustomerLoginController extends BaseCRUDJsonBodyMappingController<CustomerService, CustomerEntity, Long> {

    @Autowired
    private CustomerService customerService;
    @Autowired
    private IAuthTokenService authTokenService;

    @RequestMapping("login")
    public String login(@RequestBody LoginForm loginForm) throws Exception {
        JSONObject ret = new JSONObject();
        Map<String, Object> data = new HashMap<>();
        String loginName = loginForm.getLoginName();
        String password = loginForm.getPassword();
        String ip = super.getRequestIP(request);
        if (StringUtils.isEmpty(loginName) || StringUtils.isEmpty(password)) {
            ret.put(KEY_RESULT_CODE, VALUE_RESULT_FAILURE);
            ret.put(KEY_RESULT_MSG, "未获取到用户信息，请重新登录");
            return ret.toJSONString();
        }
        CustomerEntity customerEntity = null;
        try {
            loginForm.validate();
            customerEntity = customerService.doLogin(loginName, password, ip);
            customerEntity.setLastLoginAddress(ip);
            customerEntity.setLoginTime(System.currentTimeMillis());
            customerEntity.setToken(IdUtil.fastSimpleUUID());
            customerEntity.setExpireTime(DateUtils.addCurrDate(7).getTime());
            String token = authTokenService.createToken(customerEntity);
            data.put("token", token);
            data.put("customer", customerEntity);
            recordSysLog(request, customerEntity, "客户登录系统成功!");
            ret.put(KEY_RESULT_DATA, data);
            ret.put(KEY_RESULT_CODE, VALUE_RESULT_SUCCESS);
            ret.put(KEY_RESULT_MSG, "用户登录系统成功!");
            return ret.toJSONString();
        } catch (Exception e) {
            log.error("login error ", e);
            ret.put(KEY_RESULT_CODE, VALUE_RESULT_FAILURE);
            ret.put(KEY_RESULT_MSG, super.convertException(e));
            return ret.toJSONString();
        }
    }

    @RequestMapping("logout")
    public void logout() throws Exception {
        recordSysLog(request, "退出登录");
        super.removeCurrUser(request);
    }
}
