package com.mortals.xhx.module.customer.service.impl;
import com.mortals.framework.exception.AppException;
import com.mortals.framework.model.Context;
import com.mortals.framework.model.PageInfo;
import com.mortals.framework.model.Result;
import com.mortals.framework.util.SecurityUtil;
import com.mortals.framework.util.StringUtils;
import com.mortals.xhx.common.code.TrialAcceptEnum;
import com.mortals.xhx.module.customer.dao.CustomerDao;
import com.mortals.xhx.module.customer.model.CustomerEntity;
import com.mortals.xhx.module.customer.model.CustomerTrialEntityExt;
import com.mortals.xhx.module.customer.model.CustomerTrialQuery;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.mortals.framework.service.impl.AbstractCRUDServiceImpl;
import com.mortals.xhx.module.customer.dao.CustomerTrialDao;
import com.mortals.xhx.module.customer.model.CustomerTrialEntity;
import com.mortals.xhx.module.customer.service.CustomerTrialService;

import java.util.ArrayList;
import java.util.List;

/**
* CustomerTrialService
* 客户试用申请 service实现
*
* @author zxfei
* @date 2022-06-08
*/
@Service("customerTrialService")
public class CustomerTrialServiceImpl extends AbstractCRUDServiceImpl<CustomerTrialDao, CustomerTrialEntity, Long> implements CustomerTrialService {

    @Autowired
    private CustomerDao customerDao;

    @Override
    public Result<CustomerTrialEntityExt> findExt(CustomerTrialEntity params, PageInfo pageInfo, Context context) throws AppException {
        CustomerTrialQuery query = new CustomerTrialQuery();
        BeanUtils.copyProperties(params,query);
        if(StringUtils.isNotEmpty(params.getQuery())){
            StringBuffer condition = new StringBuffer("%");
            condition.append(params.getQuery()).append("%");
            CustomerTrialQuery condition1 = new CustomerTrialQuery();
            CustomerTrialQuery condition2 = new CustomerTrialQuery();

            condition1.setCustName(condition.toString());
            condition2.setContactTelphone(condition.toString());
            List<CustomerTrialQuery> orConditionList = new ArrayList<>();
            orConditionList.add(condition1);
            orConditionList.add(condition2);
            query.setOrConditionList(orConditionList);
        }
        return getDao().getListExt(query,pageInfo);
    }

    @Override
    public void doAccept(CustomerTrialEntity entity, Context context) throws AppException {
        CustomerTrialEntity customerTrialEntity = this.dao.get(entity.getId());
        if(customerTrialEntity==null){
            throw new AppException("请求数据不存在");
        }
        if(customerTrialEntity.getIsAccept()!=TrialAcceptEnum.NOT_ACCEPTED.getValue()){
            throw new AppException("请求数据已处理");
        }
        if(entity.getIsAccept()==null){
            throw new AppException("受理意见不能为空");
        }
        if(entity.getIsAccept()== TrialAcceptEnum.AGREE.getValue()){
            if(StringUtils.isEmpty(entity.getLoginName())){
                throw new AppException("登录账号不能为空");
            }
            if(StringUtils.isEmpty(entity.getPassword())){
                throw new AppException("登录密码不能为空");
            }
            CustomerEntity customerEntity = new CustomerEntity();
            customerEntity.setId(customerTrialEntity.getCustomerId());
            customerEntity.setLoginName(entity.getLoginName());
            try {
                customerEntity.setPassword(SecurityUtil.md5DoubleEncoding(entity.getPassword()));
            } catch (Exception e) {
                throw new AppException("密码转换异常！", e);
            }
            customerEntity.setMemberLevel(customerTrialEntity.getMemberLevel());
            customerDao.update(customerEntity);
        }
        CustomerTrialEntity update = new CustomerTrialEntity();
        update.setId(customerTrialEntity.getId());
        update.setIsAccept(entity.getIsAccept());
        this.dao.update(update);
    }
}