package com.mortals.xhx.module.customer.web;

import com.alibaba.fastjson.JSONObject;
import com.mortals.framework.annotation.UnAuth;
import com.mortals.framework.common.IBaseEnum;
import com.mortals.framework.exception.AppException;
import com.mortals.framework.model.Context;
import com.mortals.framework.model.PageInfo;
import com.mortals.framework.model.Result;
import com.mortals.framework.util.DateUtils;
import com.mortals.framework.web.BaseCRUDJsonBodyMappingController;
import com.mortals.xhx.common.code.WorkDesignStatusEnum;
import com.mortals.xhx.common.key.Constant;
import com.mortals.xhx.module.customer.model.CustomerWorkDesignEntity;
import com.mortals.xhx.module.customer.service.CustomerWorkDesignService;
import org.apache.commons.collections4.CollectionUtils;
import org.springframework.web.bind.annotation.*;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
/**
*
* 客户作品信息
*
* @author zxfei
* @date 2022-06-14
*/
@RestController
@RequestMapping("customer/work/design")
public class CustomerWorkDesignController extends BaseCRUDJsonBodyMappingController<CustomerWorkDesignService,CustomerWorkDesignEntity,Long> {

    public CustomerWorkDesignController(){
        super.setModuleDesc( "客户作品信息");
    }

    @Override
    protected void init(Map<String, Object> model, Context context) {
        this.addDict(model, "workDesignStatus", IBaseEnum.getEnumMap(WorkDesignStatusEnum.class));
        super.init(model, context);
    }

    @Override
    protected int doListAfter(CustomerWorkDesignEntity query, Map<String, Object> model, Context context) throws AppException {
        List<CustomerWorkDesignEntity> resultList = (List<CustomerWorkDesignEntity>) model.get("data");
        List<CustomerWorkDesignEntity> draft = new ArrayList<>();
        List<CustomerWorkDesignEntity> release = new ArrayList<>();
        if(CollectionUtils.isNotEmpty(resultList)){
            resultList.stream().forEach(item->{
                item.setCreateTimeStr(DateUtils.getDateTimeStr(item.getCreateTime(),DateUtils.P_yyyy_MM_dd_HH_mm_ss));
                item.setUpdateTimeStr(DateUtils.getDateTimeStr(item.getUpdateTime(),DateUtils.P_yyyy_MM_dd_HH_mm_ss));
                if(item.getWorkDesignStatus()==WorkDesignStatusEnum.DRAFT.getValue()){
                    draft.add(item);
                }else {
                    release.add(item);
                }
            });
        }
        Map<String, Object> map = new HashMap<>();
        map.put("draft",draft);
        map.put("release",release);
        model.put("data",map);
        return 1;
    }

    @Override
    protected void doListBefore(CustomerWorkDesignEntity query, Map<String, Object> model, Context context) throws AppException {
        if(this.getCurUser()==null||this.getCurUser().getUserType()!= Constant.CUSTOMER_USER){
            throw new AppException("非法用户,不可访问");
        }
        query.setCustomerId(this.getCurUser().getId());
    }

    @Override
    protected void saveBefore(CustomerWorkDesignEntity entity, Map<String, Object> model, Context context) throws AppException {
        if(this.getCurUser()==null||this.getCurUser().getUserType()!= Constant.CUSTOMER_USER){
            throw new AppException("非法用户,不可访问");
        }
        entity.setCustomerId(this.getCurUser().getId());
    }


    @PostMapping({"picture/list"})
    @UnAuth
    public String pictureList(@RequestBody CustomerWorkDesignEntity query) {
        Map<String, Object> model = new HashMap();
        JSONObject ret = new JSONObject();
        Context context = this.getContext();
        String busiDesc = "查询" + this.getModuleDesc();

        int code;
        try {
            if(query.getCustomerId()==null){
                throw new AppException("客户id不能为空");
            }
            List<CustomerWorkDesignEntity> result = this.getService().find(query, context);
            if(CollectionUtils.isNotEmpty(result)){
                result.stream().forEach(item->{
                    item.setCreateTimeStr(DateUtils.getDateTimeStr(item.getCreateTime(),DateUtils.P_yyyy_MM_dd_HH_mm_ss));
                    item.setUpdateTimeStr(DateUtils.getDateTimeStr(item.getUpdateTime(),DateUtils.P_yyyy_MM_dd_HH_mm_ss));
                });
            }
            model.put("data", result);
            code = 1;
            this.recordSysLog(this.request, busiDesc + " 【成功】");
        } catch (Exception var9) {
            code = -1;
            this.doException(this.request, busiDesc, model, var9);
        }
        this.init(model, context);
        ret.put("code", code);
        ret.put("msg", model.remove("message_info"));
        ret.put("dict", model.remove("dict"));
        ret.put("data", model);
        return ret.toJSONString();
    }
}